@@ -93,7 +93,7 @@ def _other(obj, options):
                 if isinstance(attr_value, scalar_types):
                     yield (attr, attr_value)
                 else:
-                    yield (attr, str(attr_value))
+                    yield (attr, unicode(attr_value))
             else:
                 if options['doc'] and attr == '__doc__' and attr_value:
                     yield (attr, attr_value)
@@ -142,16 +142,16 @@ def _natto(data, state, options):
         if options['func_doc']:
 
             try:
-                doc_str = '<div class="funcalike">%(funcalike)s</div><br />%(docstring)s' % {'funcalike':escape( str(data)), 'docstring':escape(data.__doc__,True)}
-                doc_str = docstring_tpl % {'expander_text':escape(str(data), True), 'docstring':doc_str}
+                doc_str = '<div class="funcalike">%(funcalike)s</div><br />%(docstring)s' % {'funcalike':escape( unicode(data)), 'docstring':escape(data.__doc__,True)}
+                doc_str = docstring_tpl % {'expander_text':escape(unicode(data), True), 'docstring':doc_str}
                 
             except AttributeError:
-                return value_tpl % {'value_type':'func' ,'value':escape(str(data), True)}
+                return value_tpl % {'value_type':'func' ,'value':escape(unicode(data), True)}
     
             return doc_str
 
         else:
-            return value_tpl % {'value_type':'func' ,'value':escape(str(data), True)}
+            return value_tpl % {'value_type':'func' ,'value':escape(unicode(data), True)}
 
     if data is None:
         return value_tpl % {'value_type':'none' ,'value':data}
@@ -176,7 +176,7 @@ def _natto(data, state, options):
             if options['max_str_len'] and len(data) > options['max_str_len']-3:
                 value = data[:options['max_str_len']]+'...'
 
-            value = str(data)
+            value = unicode(data)
 
             if options['html_highlight']:
 
@@ -274,7 +274,7 @@ def _natto(data, state, options):
         
         state['path'].append(key)
 
-        path = '.'.join( [str(item) for item in state['path']] )
+        path = '.'.join( [unicode(item) for item in state['path']] )
 
         if options['max_v'] and len(rows) >= options['max_v']:
 
@@ -330,7 +330,7 @@ def _natto(data, state, options):
             'id'         : '%s_%s' % (id(value), state['id_i'] ),
             'key_class'  : 'type_%s' % key_css_class,
             'key_title'  : key_title_tpl % {'name':type(data).__name__, 'path':path },
-            'key'        : escape(str(key)),
+            'key'        : escape(unicode(key)),
             'anchor_id'  : str(id(value)),
             'value_html' : value_html
         })
@@ -398,7 +398,7 @@ def natto(
     state = {'path':[],'visited':[], 'id_i':0, 'ids':set()}
 
     html = container_tpl % {
-        'title'   : escape(str(traceback.extract_stack()[-2]), True),
+        'title'   : escape(unicode(traceback.extract_stack()[-2]), True),
         'th'      : '{0}:{1}'.format(traceback.extract_stack()[-2][0], \
                                      traceback.extract_stack()[-2][1]),
         'label'   : options['label'],
